@@ -40,9 +40,9 @@ from typing               import List, Tuple, Union, Dict, Iterator, Optional as
 
 from pyTooling.Decorators import export
 
-from pyVHDLModel          import ModelEntity, NamedEntity, MultipleNamedEntity, LabeledEntity, PossibleReference, Direction, EntityClass, Mode
+from pyVHDLModel import ModelEntity, NamedEntityMixin, MultipleNamedEntityMixin, LabeledEntityMixin, PossibleReference, Direction, EntityClass, Mode, DocumentedEntityMixin
 from pyVHDLModel          import PrimaryUnit, SecondaryUnit
-from pyVHDLModel          import ExpressionUnion, ConstraintUnion, ContextUnion, SubtypeOrSymbol, MixinDesignUnitWithContext, PackageOrSymbol
+from pyVHDLModel          import ExpressionUnion, ConstraintUnion, ContextUnion, SubtypeOrSymbol, DesignUnitWithContextMixin, PackageOrSymbol
 from pyVHDLModel.PSLModel import VerificationUnit
 
 try:
@@ -53,7 +53,7 @@ except ImportError:
 
 
 @export
-class Name:
+class Name(ModelEntity):
 	"""``Name`` is the base-class for all *names* in the VHDL language model."""
 
 	_identifier: str
@@ -194,6 +194,7 @@ class LibrarySymbol(Symbol):
 	@property
 	def Library(self) -> 'Library':
 		return self._library
+
 	@Library.setter
 	def Library(self, value: 'Library') -> None:
 		self._reference = value
@@ -207,6 +208,7 @@ class EntitySymbol(Symbol):
 	@property
 	def Entity(self) -> 'Entity':
 		return self._reference
+
 	@Entity.setter
 	def Entity(self, value: 'Entity') -> None:
 		self._reference = value
@@ -220,6 +222,7 @@ class ArchitectureSymbol(Symbol):
 	@property
 	def Architecture(self) -> 'Architecture':
 		return self._reference
+
 	@Architecture.setter
 	def Architecture(self, value: 'Architecture') -> None:
 		self._reference = value
@@ -233,6 +236,7 @@ class ComponentSymbol(Symbol):
 	@property
 	def Component(self) -> 'Component':
 		return self._reference
+
 	@Component.setter
 	def Component(self, value: 'Component') -> None:
 		self._reference = value
@@ -246,6 +250,7 @@ class ConfigurationSymbol(Symbol):
 	@property
 	def Configuration(self) -> 'Configuration':
 		return self._reference
+
 	@Configuration.setter
 	def Configuration(self, value: 'Configuration') -> None:
 		self._reference = value
@@ -259,6 +264,7 @@ class ContextSymbol(Symbol):
 	@property
 	def Context(self) -> 'Context':
 		return self._reference
+
 	@Context.setter
 	def Context(self, value: 'Context') -> None:
 		self._reference = value
@@ -272,6 +278,7 @@ class SubtypeSymbol(Symbol):
 	@property
 	def Subtype(self) -> 'Subtype':
 		return self._reference
+
 	@Subtype.setter
 	def Subtype(self, value: 'Subtype') -> None:
 		self._reference = value
@@ -323,6 +330,7 @@ class SimpleObjectOrFunctionCallSymbol(ObjectSymbol):
 	@property
 	def ObjectOrFunction(self) -> Union['Constant', 'Signal', 'Variable', 'Function', 'EnumerationLiteral']:
 		return self._reference
+
 	@ObjectOrFunction.setter
 	def ObjectOrFunction(self, value: Union['Constant', 'Signal', 'Variable', 'Function', 'EnumerationLiteral']):
 		self._reference = value
@@ -336,6 +344,7 @@ class IndexedObjectOrFunctionCallSymbol(ObjectSymbol):
 	@property
 	def ObjectOrFunction(self) -> Union['Constant', 'Signal', 'Variable', 'Function']:
 		return self._reference
+
 	@ObjectOrFunction.setter
 	def ObjectOrFunction(self, value: Union['Constant', 'Signal', 'Variable', 'Function']):
 		self._reference = value
@@ -349,11 +358,26 @@ class ConstantSymbol(ObjectSymbol):
 	@property
 	def Constant(self) -> 'Constant':
 		return self._reference
+
 	@Constant.setter
 	def Constant(self, value: 'Constant') -> None:
 		self._reference = value
 
 
+@export
+class VariableSymbol(ObjectSymbol):
+	def __init__(self, symbolName: Name):
+		super().__init__(symbolName, PossibleReference.Constant)
+
+	@property
+	def Variable(self) -> 'Variable':
+		return self._reference
+
+	@Variable.setter
+	def Variable(self, value: 'Variable') -> None:
+		self._reference = value
+
+
 @export
 class SignalSymbol(ObjectSymbol):
 	def __init__(self, symbolName: Name):
@@ -362,6 +386,7 @@ class SignalSymbol(ObjectSymbol):
 	@property
 	def Signal(self) -> 'Signal':
 		return self._reference
+
 	@Signal.setter
 	def Signal(self, value: 'Signal') -> None:
 		self._reference = value
@@ -370,9 +395,9 @@ class SignalSymbol(ObjectSymbol):
 @export
 class Design(ModelEntity):
 	"""
-	A ``Design`` represents all loaded files (see :class:`~pyVHDLModel.VHDLModel.Document`)
+	A ``Design`` represents all loaded files (see :class:`~pyVHDLModel.SyntaxModel.Document`)
 	and analysed. It's the root of this document-object-model (DOM). It contains
-	at least on VHDL library (see :class:`~pyVHDLModel.VHDLModel.Library`).
+	at least on VHDL library (see :class:`~pyVHDLModel.SyntaxModel.Library`).
 	"""
 	_libraries:  Dict[str, 'Library']  #: List of all libraries defined for a design.
 	_documents:  List['Document']      #: List of all documents loaded for a design.
@@ -434,7 +459,7 @@ class Design(ModelEntity):
 
 
 @export
-class Library(ModelEntity, NamedEntity):
+class Library(ModelEntity, NamedEntityMixin):
 	"""A ``Library`` represents a VHDL library. It contains all *primary* design units."""
 
 	_contexts:       List['Context']                     #: List of all contexts defined in a library.
@@ -446,7 +471,7 @@ class Library(ModelEntity, NamedEntity):
 
 	def __init__(self, identifier: str):
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
 
 		self._contexts =        []
 		self._configurations =  []
@@ -487,7 +512,7 @@ class Library(ModelEntity, NamedEntity):
 
 
 @export
-class Document(ModelEntity):
+class Document(ModelEntity, DocumentedEntityMixin):
 	"""A ``Document`` represents a sourcefile. It contains primary and secondary design units."""
 
 	_path:              Path                      #: path to the document. ``None`` if virtual document.
@@ -499,8 +524,9 @@ class Document(ModelEntity):
 	_packages:          List['Package']           #: List of all packages defined in a document.
 	_packageBodies:     List['PackageBody']       #: List of all package bodies defined in a document.
 
-	def __init__(self, path: Path):
+	def __init__(self, path: Path, documentation: str = None):
 		super().__init__()
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._path =              path
 		self._contexts =          []
@@ -552,29 +578,31 @@ class Document(ModelEntity):
 
 
 @export
-class Alias(ModelEntity, NamedEntity):
-	def __init__(self, identifier: str):
+class Alias(ModelEntity, NamedEntityMixin, DocumentedEntityMixin):
+	def __init__(self, identifier: str, documentation: str = None):
 		"""
 		Initializes underlying ``BaseType``.
 
 		:param identifier: Name of the type.
 		"""
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 
 @export
-class BaseType(ModelEntity, NamedEntity):
+class BaseType(ModelEntity, NamedEntityMixin, DocumentedEntityMixin):
 	"""``BaseType`` is the base-class of all type entities in this model."""
 
-	def __init__(self, identifier: str):
+	def __init__(self, identifier: str, documentation: str = None):
 		"""
 		Initializes underlying ``BaseType``.
 
 		:param identifier: Name of the type.
 		"""
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 
 @export
@@ -781,12 +809,12 @@ class ArrayType(CompositeType):
 
 
 @export
-class RecordTypeElement(ModelEntity, MultipleNamedEntity):
+class RecordTypeElement(ModelEntity, MultipleNamedEntityMixin):
 	_subtype: SubtypeOrSymbol
 
 	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol):
 		super().__init__()
-		MultipleNamedEntity.__init__(self, identifiers)
+		MultipleNamedEntityMixin.__init__(self, identifiers)
 
 		self._subtype = subtype
 
@@ -893,7 +921,7 @@ class PhysicalLiteral(NumericLiteral):
 		return self._unitName
 
 	def __str__(self) -> str:
-		return "{value} {unit}".format(value=self._value, unit=self._unitName)
+		return f"{self._value} {self._unitName}"
 
 
 @export
@@ -994,11 +1022,7 @@ class UnaryExpression(BaseExpression):
 		return self._operand
 
 	def __str__(self) -> str:
-		return "{leftOperator}{operand!s}{rightOperator}".format(
-			leftOperator=self._FORMAT[0],
-			operand=self._operand,
-			rightOperator=self._FORMAT[1],
-		)
+		return f"{self._FORMAT[0]}{self._operand!s}{self._FORMAT[1]}"
 
 
 @export
@@ -1309,10 +1333,7 @@ class QualifiedExpression(BaseExpression, ParenthesisExpression):
 		return self._subtype
 
 	def __str__(self) -> str:
-		return "{subtype}'({operand!s})".format(
-			subtype=self._subtype,
-			operand=self._operand,
-		)
+		return f"{self._subtype}'({self._operand!s})"
 
 
 @export
@@ -1558,12 +1579,13 @@ class RangeSubtype(BaseConstraint):
 
 
 @export
-class Obj(ModelEntity, MultipleNamedEntity):
+class Obj(ModelEntity, MultipleNamedEntityMixin, DocumentedEntityMixin):
 	_subtype: SubtypeOrSymbol
 
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol):
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, documentation: str = None):
 		super().__init__()
-		MultipleNamedEntity.__init__(self, identifiers)
+		MultipleNamedEntityMixin.__init__(self, identifiers)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._subtype = subtype
 
@@ -1593,8 +1615,8 @@ class BaseConstant(Obj):
 
 @export
 class Constant(BaseConstant, WithDefaultExpressionMixin):
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype)
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, documentation)
 		WithDefaultExpressionMixin.__init__(self, defaultExpression)
 
 
@@ -1602,8 +1624,8 @@ class Constant(BaseConstant, WithDefaultExpressionMixin):
 class DeferredConstant(BaseConstant):
 	_constantReference: Constant
 
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol):
-		super().__init__(identifiers, subtype)
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, documentation: str = None):
+		super().__init__(identifiers, subtype, documentation)
 
 	@property
 	def ConstantReference(self) -> Constant:
@@ -1612,8 +1634,8 @@ class DeferredConstant(BaseConstant):
 
 @export
 class Variable(Obj, WithDefaultExpressionMixin):
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype)
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, documentation)
 		WithDefaultExpressionMixin.__init__(self, defaultExpression)
 
 
@@ -1624,8 +1646,8 @@ class SharedVariable(Obj):
 
 @export
 class Signal(Obj, WithDefaultExpressionMixin):
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super(Signal, self).__init__(identifiers, subtype)
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, documentation)
 		WithDefaultExpressionMixin.__init__(self, defaultExpression)
 
 
@@ -1635,16 +1657,17 @@ class File(Obj):
 
 
 @export
-class SubProgramm(ModelEntity, NamedEntity):
+class SubProgramm(ModelEntity, NamedEntityMixin, DocumentedEntityMixin):
 	_genericItems:   List['GenericInterfaceItem']
 	_parameterItems: List['ParameterInterfaceItem']
 	_declaredItems:  List
 	_statements:     List['SequentialStatement']
 	_isPure:         bool
 
-	def __init__(self, identifier: str):
+	def __init__(self, identifier: str, documentation: str = None):
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._genericItems =    []
 		self._parameterItems =  []
@@ -1681,8 +1704,8 @@ class Procedure(SubProgramm):
 class Function(SubProgramm):
 	_returnType: Subtype
 
-	def __init__(self, identifier: str, isPure: bool = True):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, isPure: bool = True, documentation: str = None):
+		super().__init__(identifier, documentation)
 		self._isPure = isPure
 
 	@property
@@ -1719,12 +1742,13 @@ class FunctionMethod(Function, Method):
 
 
 @export
-class Attribute(ModelEntity, NamedEntity):
+class Attribute(ModelEntity, NamedEntityMixin, DocumentedEntityMixin):
 	_subtype: SubtypeOrSymbol
 
-	def __init__(self, identifier: str, subtype: SubtypeOrSymbol):
+	def __init__(self, identifier: str, subtype: SubtypeOrSymbol, documentation: str = None):
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._subtype = subtype
 
@@ -1734,14 +1758,15 @@ class Attribute(ModelEntity, NamedEntity):
 
 
 @export
-class AttributeSpecification(ModelEntity):
+class AttributeSpecification(ModelEntity, DocumentedEntityMixin):
 	_identifiers: List[Name]
 	_attribute: Name
 	_entityClass: EntityClass
 	_expression: ExpressionUnion
 
-	def __init__(self, identifiers: Iterable[Name], attribute: Name, entityClass: EntityClass, expression: ExpressionUnion):
+	def __init__(self, identifiers: Iterable[Name], attribute: Name, entityClass: EntityClass, expression: ExpressionUnion, documentation: str = None):
 		super().__init__()
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._identifiers = [i for i in identifiers]
 		self._attribute = attribute
@@ -1766,11 +1791,11 @@ class AttributeSpecification(ModelEntity):
 
 
 @export
-class InterfaceItem:
+class InterfaceItem(DocumentedEntityMixin):
 	"""An ``InterfaceItem`` is a base-class for all mixin-classes for all interface items."""
 
-	def __init__(self):
-		pass
+	def __init__(self, documentation: str = None):
+		super().__init__(documentation)
 
 
 @export
@@ -1808,16 +1833,16 @@ class ParameterInterfaceItem(InterfaceItem):
 
 @export
 class GenericConstantInterfaceItem(Constant, GenericInterfaceItem, InterfaceItemWithMode):
-	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype, defaultExpression)
+	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, defaultExpression, documentation)
 		GenericInterfaceItem.__init__(self)
 		InterfaceItemWithMode.__init__(self, mode)
 
 
 @export
 class GenericTypeInterfaceItem(Type, GenericInterfaceItem):
-	def __init__(self, identifier: str):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, documentation: str = None):
+		super().__init__(identifier, documentation)
 		GenericInterfaceItem.__init__(self)
 
 
@@ -1828,60 +1853,60 @@ class GenericSubprogramInterfaceItem(GenericInterfaceItem):
 
 @export
 class GenericProcedureInterfaceItem(Procedure, GenericInterfaceItem):
-	def __init__(self, identifier: str):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, documentation: str = None):
+		super().__init__(identifier, documentation)
 		GenericInterfaceItem.__init__(self)
 
 
 @export
 class GenericFunctionInterfaceItem(Function, GenericInterfaceItem):
-	def __init__(self, identifier: str):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, documentation: str = None):
+		super().__init__(identifier, documentation)
 		GenericInterfaceItem.__init__(self)
 
 
 @export
 class GenericPackageInterfaceItem(GenericInterfaceItem):
-	def __init__(self, identifier: str):
-		#	super().__init__(identifier)
+	def __init__(self, identifier: str, documentation: str = None):
+		#	super().__init__(identifier, documentation)
 		GenericInterfaceItem.__init__(self)
 
 
 @export
 class PortSignalInterfaceItem(Signal, PortInterfaceItem):
-	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype, defaultExpression)
+	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, defaultExpression, documentation)
 		PortInterfaceItem.__init__(self, mode)
 
 
 @export
 class ParameterConstantInterfaceItem(Constant, ParameterInterfaceItem, InterfaceItemWithMode):
-	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype, defaultExpression)
+	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, defaultExpression, documentation)
 		ParameterInterfaceItem.__init__(self)
 		InterfaceItemWithMode.__init__(self, mode)
 
 
 @export
 class ParameterVariableInterfaceItem(Variable, ParameterInterfaceItem, InterfaceItemWithMode):
-	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype, defaultExpression)
+	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, defaultExpression, documentation)
 		ParameterInterfaceItem.__init__(self)
 		InterfaceItemWithMode.__init__(self, mode)
 
 
 @export
 class ParameterSignalInterfaceItem(Signal, ParameterInterfaceItem, InterfaceItemWithMode):
-	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None):
-		super().__init__(identifiers, subtype, defaultExpression)
+	def __init__(self, identifiers: Iterable[str], mode: Mode, subtype: SubtypeOrSymbol, defaultExpression: ExpressionUnion = None, documentation: str = None):
+		super().__init__(identifiers, subtype, defaultExpression, documentation)
 		ParameterInterfaceItem.__init__(self)
 		InterfaceItemWithMode.__init__(self, mode)
 
 
 @export
 class ParameterFileInterfaceItem(File, ParameterInterfaceItem):
-	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol):
-		super().__init__(identifiers, subtype)
+	def __init__(self, identifiers: Iterable[str], subtype: SubtypeOrSymbol, documentation: str = None):
+		super().__init__(identifiers, subtype, documentation)
 		ParameterInterfaceItem.__init__(self)
 
 
@@ -1919,8 +1944,8 @@ class Context(PrimaryUnit):
 	_libraryReferences: List[LibraryClause]
 	_packageReferences: List[UseClause]
 
-	def __init__(self, identifier: str, libraryReferences: Iterable[LibraryClause] = None, packageReferences: Iterable[UseClause] = None):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, libraryReferences: Iterable[LibraryClause] = None, packageReferences: Iterable[UseClause] = None, documentation: str = None):
+		super().__init__(identifier, documentation)
 
 		self._libraryReferences = [] if libraryReferences is None else [l for l in libraryReferences]
 		self._packageReferences = [] if packageReferences is None else [p for p in packageReferences]
@@ -1935,7 +1960,7 @@ class Context(PrimaryUnit):
 
 
 @export
-class Entity(PrimaryUnit, MixinDesignUnitWithContext):
+class Entity(PrimaryUnit, DesignUnitWithContextMixin):
 	_genericItems:  List[GenericInterfaceItem]
 	_portItems:     List[PortInterfaceItem]
 	_declaredItems: List   # FIXME: define list prefix type e.g. via Union
@@ -1949,10 +1974,11 @@ class Entity(PrimaryUnit, MixinDesignUnitWithContext):
 		genericItems: Iterable[GenericInterfaceItem] = None,
 		portItems: Iterable[PortInterfaceItem] = None,
 		declaredItems: Iterable = None,
-		statements: Iterable['ConcurrentStatement'] = None
+		statements: Iterable['ConcurrentStatement'] = None,
+		documentation: str = None
 	):
-		super().__init__(identifier)
-		MixinDesignUnitWithContext.__init__(self, contextItems)
+		super().__init__(identifier, documentation)
+		DesignUnitWithContextMixin.__init__(self, contextItems)
 
 		self._genericItems  = [] if genericItems is None else [g for g in genericItems]
 		self._portItems     = [] if portItems is None else [p for p in portItems]
@@ -1982,15 +2008,15 @@ class Entity(PrimaryUnit, MixinDesignUnitWithContext):
 
 
 @export
-class Architecture(SecondaryUnit, MixinDesignUnitWithContext):
+class Architecture(SecondaryUnit, DesignUnitWithContextMixin):
 	_library:       Library = None
 	_entity:        EntitySymbol
 	_declaredItems: List   # FIXME: define list prefix type e.g. via Union
 	_statements:    List['ConcurrentStatement']
 
-	def __init__(self, identifier: str, entity: Name, contextItems: Iterable[Context] = None, declaredItems: Iterable = None, statements: Iterable['ConcurrentStatement'] = None):
-		super().__init__(identifier)
-		MixinDesignUnitWithContext.__init__(self, contextItems)
+	def __init__(self, identifier: str, entity: Name, contextItems: Iterable[Context] = None, declaredItems: Iterable = None, statements: Iterable['ConcurrentStatement'] = None, documentation: str = None):
+		super().__init__(identifier, documentation)
+		DesignUnitWithContextMixin.__init__(self, contextItems)
 
 		self._entity        = EntitySymbol(entity)
 		self._declaredItems = [] if declaredItems is None else [i for i in declaredItems]
@@ -2017,13 +2043,14 @@ class Architecture(SecondaryUnit, MixinDesignUnitWithContext):
 
 
 @export
-class Component(ModelEntity, NamedEntity):
+class Component(ModelEntity, NamedEntityMixin, DocumentedEntityMixin):
 	_genericItems:      List[GenericInterfaceItem]
 	_portItems:         List[PortInterfaceItem]
 
-	def __init__(self, identifier: str, genericItems: Iterable[GenericInterfaceItem] = None, portItems: Iterable[PortInterfaceItem] = None):
+	def __init__(self, identifier: str, genericItems: Iterable[GenericInterfaceItem] = None, portItems: Iterable[PortInterfaceItem] = None, documentation: str = None):
 		super().__init__()
-		NamedEntity.__init__(self, identifier)
+		NamedEntityMixin.__init__(self, identifier)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._genericItems      = [] if genericItems is None else [g for g in genericItems]
 		self._portItems         = [] if portItems is None else [p for p in portItems]
@@ -2038,10 +2065,10 @@ class Component(ModelEntity, NamedEntity):
 
 
 @export
-class Configuration(PrimaryUnit, MixinDesignUnitWithContext):
-	def __init__(self, identifier: str, contextItems: Iterable[Context] = None):
-		super().__init__(identifier)
-		MixinDesignUnitWithContext.__init__(self, contextItems)
+class Configuration(PrimaryUnit, DesignUnitWithContextMixin):
+	def __init__(self, identifier: str, contextItems: Iterable[Context] = None, documentation: str = None):
+		super().__init__(identifier, documentation)
+		DesignUnitWithContextMixin.__init__(self, contextItems)
 
 
 @export
@@ -2110,13 +2137,13 @@ class FunctionInstantiation(Function, SubprogramInstantiation):
 
 
 @export
-class Package(PrimaryUnit, MixinDesignUnitWithContext):
+class Package(PrimaryUnit, DesignUnitWithContextMixin):
 	_genericItems:      List[GenericInterfaceItem]
 	_declaredItems:     List
 
-	def __init__(self, identifier: str, contextItems: Iterable[Context] = None, genericItems: Iterable[GenericInterfaceItem] = None, declaredItems: Iterable = None):
-		super().__init__(identifier)
-		MixinDesignUnitWithContext.__init__(self, contextItems)
+	def __init__(self, identifier: str, contextItems: Iterable[Context] = None, genericItems: Iterable[GenericInterfaceItem] = None, declaredItems: Iterable = None, documentation: str = None):
+		super().__init__(identifier, documentation)
+		DesignUnitWithContextMixin.__init__(self, contextItems)
 
 		self._genericItems =  [] if genericItems is None else [g for g in genericItems]
 		self._declaredItems = [] if declaredItems is None else [i for i in declaredItems]
@@ -2131,13 +2158,13 @@ class Package(PrimaryUnit, MixinDesignUnitWithContext):
 
 
 @export
-class PackageBody(SecondaryUnit, MixinDesignUnitWithContext):
+class PackageBody(SecondaryUnit, DesignUnitWithContextMixin):
 	_package:           Package
 	_declaredItems:     List
 
-	def __init__(self, identifier: str, contextItems: Iterable[Context] = None, declaredItems: Iterable = None):
-		super().__init__(identifier)
-		MixinDesignUnitWithContext.__init__(self, contextItems)
+	def __init__(self, identifier: str, contextItems: Iterable[Context] = None, declaredItems: Iterable = None, documentation: str = None):
+		super().__init__(identifier, documentation)
+		DesignUnitWithContextMixin.__init__(self, contextItems)
 
 		self._declaredItems = [] if declaredItems is None else [i for i in declaredItems]
 
@@ -2155,8 +2182,8 @@ class PackageInstantiation(PrimaryUnit, GenericEntityInstantiation):
 	_packageReference:    Package
 	_genericAssociations: List[GenericAssociationItem]
 
-	def __init__(self, identifier: str, uninstantiatedPackage: PackageOrSymbol):
-		super().__init__(identifier)
+	def __init__(self, identifier: str, uninstantiatedPackage: PackageOrSymbol, documentation: str = None):
+		super().__init__(identifier, documentation)
 		GenericEntityInstantiation.__init__(self)
 
 		self._packageReference = uninstantiatedPackage
@@ -2172,10 +2199,10 @@ class PackageInstantiation(PrimaryUnit, GenericEntityInstantiation):
 
 
 @export
-class Statement(ModelEntity, LabeledEntity):
+class Statement(ModelEntity, LabeledEntityMixin):
 	def __init__(self, label: str = None):
 		super().__init__()
-		LabeledEntity.__init__(self, label)
+		LabeledEntityMixin.__init__(self, label)
 
 
 @export
@@ -2188,6 +2215,7 @@ class SequentialStatement(Statement):
 	"""A ``SequentialStatement`` is a base-class for all sequential statements."""
 
 
+# FIXME: Why not used in entity, architecture, package, package body, block-statement, generate-statements
 @export
 class ConcurrentDeclarations:
 	_declaredItems: List
@@ -2200,6 +2228,7 @@ class ConcurrentDeclarations:
 		return self._declaredItems
 
 
+# FIXME: Why not used in entity, architecture, block-statement, generate-statements
 @export
 class ConcurrentStatements:
 	_statements: List[ConcurrentStatement]
@@ -2305,13 +2334,21 @@ class ConfigurationInstantiation(Instantiation):
 
 
 @export
-class ProcessStatement(ConcurrentStatement, SequentialDeclarations, SequentialStatements):
+class ProcessStatement(ConcurrentStatement, SequentialDeclarations, SequentialStatements, DocumentedEntityMixin):
 	_sensitivityList: List[Name] = None
 
-	def __init__(self, label: str = None, declaredItems: Iterable = None, statements: Iterable[SequentialStatement] = None, sensitivityList: Iterable[Name] = None):
+	def __init__(
+		self,
+		label: str = None,
+		declaredItems: Iterable = None,
+		statements: Iterable[SequentialStatement] = None,
+		sensitivityList: Iterable[Name] = None,
+		documentation: str = None
+	):
 		super().__init__(label)
 		SequentialDeclarations.__init__(self, declaredItems)
 		SequentialStatements.__init__(self, statements)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		if sensitivityList is not None:
 			self._sensitivityList = [s for s in sensitivityList]
@@ -2362,15 +2399,23 @@ class BlockStatement:
 
 
 @export
-class ConcurrentBlockStatement(ConcurrentStatement, BlockStatement, LabeledEntity, ConcurrentDeclarations, ConcurrentStatements):
+class ConcurrentBlockStatement(ConcurrentStatement, BlockStatement, LabeledEntityMixin, ConcurrentDeclarations, ConcurrentStatements, DocumentedEntityMixin):
 	_portItems:     List[PortInterfaceItem]
 
-	def __init__(self, label: str, portItems: Iterable[PortInterfaceItem] = None, declaredItems: Iterable = None, statements: Iterable['ConcurrentStatement'] = None):
+	def __init__(
+		self,
+		label: str,
+		portItems: Iterable[PortInterfaceItem] = None,
+		declaredItems: Iterable = None,
+		statements: Iterable['ConcurrentStatement'] = None,
+		documentation: str = None
+	):
 		super().__init__(label)
 		BlockStatement.__init__(self)
-		LabeledEntity.__init__(self, label)
+		LabeledEntityMixin.__init__(self, label)
 		ConcurrentDeclarations.__init__(self)
 		ConcurrentStatements.__init__(self)
+		DocumentedEntityMixin.__init__(self, documentation)
 
 		self._portItems     = [] if portItems is None else [i for i in portItems]
 		self._declaredItems = [] if declaredItems is None else [i for i in declaredItems]
@@ -2527,10 +2572,10 @@ class BaseCase(ModelEntity):
 
 
 @export
-class ConcurrentCase(BaseCase, LabeledEntity, ConcurrentDeclarations, ConcurrentStatements):
+class ConcurrentCase(BaseCase, LabeledEntityMixin, ConcurrentDeclarations, ConcurrentStatements):
 	def __init__(self, declaredItems: Iterable = None, statements: Iterable[ConcurrentStatement] = None, alternativeLabel: str = None):
 		super().__init__()
-		LabeledEntity.__init__(self, alternativeLabel)
+		LabeledEntityMixin.__init__(self, alternativeLabel)
 		ConcurrentDeclarations.__init__(self, declaredItems)
 		ConcurrentStatements.__init__(self, statements)
 
